==> crawlMp-0.3.3.tar.gz: crawlMp-0.3.3/crawlMp/actions/action_fs.py <==
import os.path
from os import remove
from shutil import copy, SameFileError, move

from crawlMp import ActionException
from crawlMp.actions.action import Action


class Copy(Action):
    """
    Copy file or folder.
    """

    def __init__(self, target_dir: str, *args, **kwargs) -> None:
        """
        :param str target_dir: target directory for a copy
        :param args:
        :param kwargs:
        """
        Action.__init__(self, *args, **kwargs)
        self.target_dir = target_dir
        if not os.path.isdir(self.target_dir):
            # Target dir does not exist, try to create it
            try:
                os.mkdir(self.target_dir)
            except OSError as e:
                raise ActionException(e)

    def do(self, link: str) -> str:
        """
        Copy input link and return path to copied link.
        :param str link: input link
        :return str: path to copied link
        """
        try:
            return copy(link, self.target_dir)
        except SameFileError:
            # File already exists, this is valid outcome, so just return new path.
            return os.path.join(self.target_dir, os.path.basename(link))
        except FileNotFoundError as exception:
            raise ActionException(exception)


class Move(Action):
    """
    Move file or folder.
    """

    def __init__(self, target_dir: str, *args, **kwargs) -> None:
        """
        :param str target_dir: target directory for a moved link
        :param args:
        :param kwargs:
        """
        Action.__init__(self, *args, **kwargs)
        self.target_dir = target_dir
        if not os.path.isdir(self.target_dir):
            # Target dir does not exist, try to create it
            try:
                os.mkdir(self.target_dir)
            except OSError as e:
                raise ActionException(e)

    def do(self, link: str) -> str:
        """
        Move input link and return path to moved link.
        :param str link: input link
        :return str: path to moved link
        """
        try:
            return move(link, self.target_dir)
        except PermissionError as exception:
            raise ActionException(exception)


class Remove(Action):
    """
    Remove file or folder.
    """

    def __init__(self, *args, **kwargs) -> None:
        """
        :param args:
        :param kwargs:
        """
        Action.__init__(self, *args, **kwargs)

    def do(self, link: str) -> None:
        """
        Remove link and return None.
        :param str link: input link
        :return: None
        """
        try:
            remove(link)
            return None
        except PermissionError as exception:
            raise ActionException(exception)
        except FileNotFoundError as exception:
            raise ActionException(exception)

==> crawlMp-0.3.4.tar.gz: crawlMp-0.3.4/crawlMp/actions/action_fs.py <==
import os.path
from os import remove
from shutil import copy, SameFileError, move

from crawlMp import ActionException
from crawlMp.actions.action import Action


class TargetDir:
    _target_dir = None

    @property
    def target_dir(self):
        return self._target_dir

    @target_dir.setter
    def target_dir(self, new_target_dir):
        if not os.path.isdir(new_target_dir):
            # Target dir does not exist, try to create it
            try:
                os.mkdir(new_target_dir)
            except OSError as e:
                raise ActionException(e)
        self._target_dir = new_target_dir


class Copy(Action, TargetDir):
    """
    Copy file or folder.
    """

    def __init__(self, target_dir: str, *args, **kwargs) -> None:
        """
        :param str target_dir: target directory for a copy
        :param args:
        :param kwargs:
        """
        self.target_dir = target_dir
        super().__init__(*args, **kwargs)

    def do(self, link: str) -> str:
        """
        Copy input link and return path to copied link.
        :param str link: input link
        :return str: path to copied link
        """
        try:
            return copy(link, self.target_dir)
        except SameFileError:
            # File already exists, this is valid outcome, so just return new path.
            return os.path.join(self.target_dir, os.path.basename(link))
        except FileNotFoundError as exception:
            raise ActionException(exception)


class Move(Action, TargetDir):
    """
    Move file or folder.
    """

    def __init__(self, target_dir: str, *args, **kwargs) -> None:
        """
        :param str target_dir: target directory for a moved link
        :param args:
        :param kwargs:
        """
        self.target_dir = target_dir
        super().__init__(*args, **kwargs)

    def do(self, link: str) -> str:
        """
        Move input link and return path to moved link.
        :param str link: input link
        :return str: path to moved link
        """
        try:
            return move(link, self.target_dir)
        except PermissionError as exception:
            raise ActionException(exception)


class Remove(Action):
    """
    Remove file or folder.
    """

    def do(self, link: str) -> None:
        """
        Remove link and return None.
        :param str link: input link
        :return: None
        """
        try:
            remove(link)
            return None
        except PermissionError as exception:
            raise ActionException(exception)
        except FileNotFoundError as exception:
            raise ActionException(exception)
